instrument
==========

`instrument <http://github.com/wearpants/instrument>`__ provides instrumentation primitives for metrics and benchmarking. It can be used to:

* monitor runtime behavior in production systems
* conduct performance benchmarks
* easily generate plots/graphs and statistics

Get it from PyPI today:

  `pip install instrument`

Python `Instrument` was formerly known as `Measure It`.

:author: Pete Fein <pete@wearpants.org>
:license: BSD
:versions: Python 2.7 & 3
:source: https://github.com/wearpants/instrument
:homepage: https://instrument.readthedocs.org/en/latest/
:video: https://www.youtube.com/watch?v=A_C4Z4RDDgI

